intervaltreetools.calculate_min_mean_and_max_magnitude_of_intervals
===================================================================

.. autofunction:: abjad.tools.intervaltreetools.calculate_min_mean_and_max_magnitude_of_intervals
